Tuning transparency of colormaps
--------------------------------
The new method `.Colormap.with_alpha` allows to create a new colormap with the same
color values but a new uniform alpha value. This is handy if you want to modify only
the transparency of mapped colors for an Artist.
